//Copyright 2005 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.

package satsa;

import javax.microedition.lcdui.List;
import javax.microedition.rms.RecordEnumeration;
import javax.microedition.rms.RecordStore;
import javax.microedition.rms.RecordStoreException;

// Stores the messages as byte arrays in the RMS
class MessageStore
{
  private final SATSAMIDlet midlet;
  private RecordStore recordStore;
  private RecordEnumeration recordEnumeration;
  private int[] messageIdArray;
  private int numberOfMessages;

  MessageStore(SATSAMIDlet midlet)
  {
    this.midlet = midlet;
    openMessageStore();
  }

  void close()
  {
    try 
    {
      recordStore.closeRecordStore();
    }
    catch (RecordStoreException rse)
    {
      // Ignore, since the application is closing anyway.
    }
  }

  // List all messages in Record Store
  void fillList(List list)
  {
    list.deleteAll();

    try
    {
      numberOfMessages = recordStore.getNumRecords();
      messageIdArray = new int[numberOfMessages+1];

      recordEnumeration = recordStore.enumerateRecords(null,
          null,
          false);
      int i=0;

      while (recordEnumeration.hasNextElement())
      {
        i++;
        int id=recordEnumeration.nextRecordId();

        list.append("Message " + id, null);
        messageIdArray[i]=id;
      }
    }
    catch (RecordStoreException rse)
    {
      midlet.showError("Record Store Exception. " + rse.getMessage());
    }
  }

  // Add a record to Record Store
  void addMessage(byte[] messageData)
  {
    try
    {
      recordStore.addRecord(messageData, 0, messageData.length);
    }
    catch (RecordStoreException rse)
    {
      midlet.showError("Record Store Exception. " + rse.getMessage());
    }
  }

  // Get message from Record Store
  byte[] getMessage(int index)
  {
    try
    {
      byte[] messageData = recordStore.getRecord(messageIdArray[index]);
      return messageData;
    }
    catch (RecordStoreException rse)
    {
      midlet.showError("Record Store Exception. " + rse.getMessage());
      return null;
    }
  }

  // Delete a record from Record Store
  void deleteMessage(int index)
  {
    try
    {
      recordStore.deleteRecord(messageIdArray[index]);
    }
    catch (RecordStoreException rse)
    {
      midlet.showError("Record Store Exception. " + rse.getMessage());
    }
  }
  
  private void openMessageStore()
  {
    try 
    {
      recordStore = RecordStore.openRecordStore("SATSA_test", true);
    }
    catch (RecordStoreException rse)
    {
      midlet.showError("Record Store Exception. " + rse.getMessage());
    }
  }
}